@@ -22,6 +22,7 @@ import logging
 from glanceclient.common import utils as gc_utils
 from openstack.image import image_signer
 from osc_lib.api import utils as api_utils
+from osc_lib.cli import format_columns
 from osc_lib.cli import parseractions
 from osc_lib.command import command
 from osc_lib import exceptions
@@ -65,11 +66,11 @@ def _format_image(image):
             properties[key] = image.get(key)
 
     # format the tags if they are there
-    info['tags'] = utils.format_list(image.get('tags'))
+    info['tags'] = format_columns.ListColumn(image.get('tags'))
 
     # add properties back into the dictionary as a top-level key
     if properties:
-        info['properties'] = utils.format_dict(properties)
+        info['properties'] = format_columns.DictColumn(properties)
 
     return info
 
@@ -250,20 +251,11 @@ class CreateImage(command.ShowOne):
             help=_("Set a tag on this image "
                    "(repeat option to set multiple tags)"),
         )
-        # NOTE(dtroyer): --owner is deprecated in Jan 2016 in an early
-        #                2.x release.  Do not remove before Jan 2017
-        #                and a 3.x release.
-        project_group = parser.add_mutually_exclusive_group()
-        project_group.add_argument(
+        parser.add_argument(
             "--project",
             metavar="<project>",
             help=_("Set an alternate project on this image (name or ID)"),
         )
-        project_group.add_argument(
-            "--owner",
-            metavar="<project>",
-            help=argparse.SUPPRESS,
-        )
         common.add_project_domain_option_to_parser(parser)
         for deadopt in self.deadopts:
             parser.add_argument(
@@ -321,16 +313,10 @@ class CreateImage(command.ShowOne):
             kwargs['visibility'] = 'community'
         if parsed_args.shared:
             kwargs['visibility'] = 'shared'
-        # Handle deprecated --owner option
-        project_arg = parsed_args.project
-        if parsed_args.owner:
-            project_arg = parsed_args.owner
-            LOG.warning(_('The --owner option is deprecated, '
-                          'please use --project instead.'))
-        if project_arg:
+        if parsed_args.project:
             kwargs['owner'] = common.find_project(
                 identity_client,
-                project_arg,
+                parsed_args.project,
                 parsed_args.project_domain,
             ).id
 
@@ -347,13 +333,6 @@ class CreateImage(command.ShowOne):
             LOG.warning(_("Failed to get an image file."))
             return {}, {}
 
-        if parsed_args.owner:
-            kwargs['owner'] = common.find_project(
-                identity_client,
-                parsed_args.owner,
-                parsed_args.project_domain,
-            ).id
-
         # sign an image using a given local private key file
         if parsed_args.sign_key_path or parsed_args.sign_cert_id:
             if not parsed_args.file:
@@ -678,7 +657,7 @@ class ListImage(command.Lister):
                 s,
                 columns,
                 formatters={
-                    'tags': utils.format_list,
+                    'tags': format_columns.ListColumn,
                 },
             ) for s in data)
         )
@@ -933,20 +912,11 @@ class SetImage(command.Command):
             action="store_true",
             help=_("Activate the image"),
         )
-        # NOTE(dtroyer): --owner is deprecated in Jan 2016 in an early
-        #                2.x release.  Do not remove before Jan 2017
-        #                and a 3.x release.
-        project_group = parser.add_mutually_exclusive_group()
-        project_group.add_argument(
+        parser.add_argument(
             "--project",
             metavar="<project>",
             help=_("Set an alternate project on this image (name or ID)"),
         )
-        project_group.add_argument(
-            "--owner",
-            metavar="<project>",
-            help=argparse.SUPPRESS,
-        )
         common.add_project_domain_option_to_parser(parser)
         for deadopt in self.deadopts:
             parser.add_argument(
@@ -1020,17 +990,11 @@ class SetImage(command.Command):
             kwargs['visibility'] = 'community'
         if parsed_args.shared:
             kwargs['visibility'] = 'shared'
-        # Handle deprecated --owner option
-        project_arg = parsed_args.project
-        if parsed_args.owner:
-            project_arg = parsed_args.owner
-            LOG.warning(_('The --owner option is deprecated, '
-                          'please use --project instead.'))
         project_id = None
-        if project_arg:
+        if parsed_args.project:
             project_id = common.find_project(
                 identity_client,
-                project_arg,
+                parsed_args.project,
                 parsed_args.project_domain,
             ).id
             kwargs['owner'] = project_id
