@@ -13,11 +13,12 @@
 
 """Router action implementations"""
 
-import argparse
 import copy
 import json
 import logging
 
+from cliff import columns as cliff_columns
+from osc_lib.cli import format_columns
 from osc_lib.cli import parseractions
 from osc_lib.command import command
 from osc_lib import exceptions
@@ -32,33 +33,37 @@ from openstackclient.network.v2 import _tag
 LOG = logging.getLogger(__name__)
 
 
-def _format_admin_state(state):
-    return 'UP' if state else 'DOWN'
+class AdminStateColumn(cliff_columns.FormattableColumn):
+    def human_readable(self):
+        return 'UP' if self._value else 'DOWN'
 
 
-def _format_router_info(info):
-    try:
-        return json.dumps(info)
-    except (TypeError, KeyError):
-        return ''
+class RouterInfoColumn(cliff_columns.FormattableColumn):
+    def human_readable(self):
+        try:
+            return json.dumps(self._value)
+        except (TypeError, KeyError):
+            return ''
 
 
-def _format_routes(routes):
-    # Map the route keys to match --route option.
-    for route in routes:
-        if 'nexthop' in route:
-            route['gateway'] = route.pop('nexthop')
-    return utils.format_list_of_dicts(routes)
+class RoutesColumn(cliff_columns.FormattableColumn):
+    def human_readable(self):
+        # Map the route keys to match --route option.
+        for route in self._value:
+            if 'nexthop' in route:
+                route['gateway'] = route.pop('nexthop')
+        return utils.format_list_of_dicts(self._value)
 
 
 _formatters = {
-    'admin_state_up': _format_admin_state,
-    'is_admin_state_up': _format_admin_state,
-    'external_gateway_info': _format_router_info,
-    'availability_zones': utils.format_list,
-    'availability_zone_hints': utils.format_list,
-    'routes': _format_routes,
-    'tags': utils.format_list,
+    'admin_state_up': AdminStateColumn,
+    'is_admin_state_up': AdminStateColumn,
+    'external_gateway_info': RouterInfoColumn,
+    'availability_zones': format_columns.ListColumn,
+    'availability_zone_hints': format_columns.ListColumn,
+    'location': format_columns.DictColumn,
+    'routes': RoutesColumn,
+    'tags': format_columns.ListColumn,
 }
 
 
@@ -528,8 +533,6 @@ class SetRouter(command.Command):
             action='store_true',
             help=_("Set router to centralized mode (disabled router only)")
         )
-        routes_group = parser.add_mutually_exclusive_group()
-        # ToDo(Reedip):Remove mutual exclusiveness once clear-routes is removed
         parser.add_argument(
             '--route',
             metavar='destination=<subnet>,gateway=<ip-address>',
@@ -542,18 +545,13 @@ class SetRouter(command.Command):
                    "gateway: nexthop IP address "
                    "(repeat option to set multiple routes)")
         )
-        routes_group.add_argument(
+        parser.add_argument(
             '--no-route',
             action='store_true',
             help=_("Clear routes associated with the router. "
                    "Specify both --route and --no-route to overwrite "
                    "current value of route.")
         )
-        routes_group.add_argument(
-            '--clear-routes',
-            action='store_true',
-            help=argparse.SUPPRESS,
-        )
         routes_ha = parser.add_mutually_exclusive_group()
         routes_ha.add_argument(
             '--ha',
@@ -619,21 +617,16 @@ class SetRouter(command.Command):
             attrs['ha'] = True
         elif parsed_args.no_ha:
             attrs['ha'] = False
-        if parsed_args.clear_routes:
-            LOG.warning(_(
-                'The --clear-routes option is deprecated, '
-                'please use --no-route instead.'
-            ))
 
         if parsed_args.routes is not None:
             for route in parsed_args.routes:
                 route['nexthop'] = route.pop('gateway')
             attrs['routes'] = parsed_args.routes
-            if not (parsed_args.no_route or parsed_args.clear_routes):
+            if not parsed_args.no_route:
                 # Map the route keys and append to the current routes.
                 # The REST API will handle route validation and duplicates.
                 attrs['routes'] += obj.routes
-        elif parsed_args.no_route or parsed_args.clear_routes:
+        elif parsed_args.no_route:
             attrs['routes'] = []
         if (parsed_args.disable_snat or parsed_args.enable_snat or
                 parsed_args.fixed_ip) and not parsed_args.external_gateway:
@@ -720,7 +713,7 @@ class ShowRouter(command.ShowOne):
 
         setattr(obj, 'interfaces_info', interfaces_info)
         display_columns, columns = _get_columns(obj)
-        _formatters['interfaces_info'] = _format_router_info
+        _formatters['interfaces_info'] = RouterInfoColumn
         data = utils.get_item_properties(obj, columns, formatters=_formatters)
 
         return (display_columns, data)
