@@ -16,6 +16,7 @@
 import argparse
 import logging
 
+from osc_lib.cli import format_columns
 from osc_lib.cli import parseractions
 from osc_lib import exceptions
 from osc_lib import utils
@@ -31,6 +32,11 @@ from openstackclient.network import utils as network_utils
 LOG = logging.getLogger(__name__)
 
 
+_formatters = {
+    'location': format_columns.DictColumn,
+}
+
+
 def _format_security_group_rule_show(obj):
     data = network_utils.transform_compute_security_group_rule(obj)
     return zip(*sorted(six.iteritems(data)))
@@ -62,6 +68,17 @@ def _format_network_port_range(rule):
     return port_range
 
 
+def _format_remote_ip_prefix(rule):
+    remote_ip_prefix = rule['remote_ip_prefix']
+    if remote_ip_prefix is None:
+        ethertype = rule['ether_type']
+        if ethertype == 'IPv4':
+            remote_ip_prefix = '0.0.0.0/0'
+        elif ethertype == 'IPv6':
+            remote_ip_prefix = '::/0'
+    return remote_ip_prefix
+
+
 def _get_columns(item):
     column_map = {
         'tenant_id': 'project_id',
@@ -108,26 +125,14 @@ class CreateSecurityGroupRule(common.NetworkAndComputeShowOne):
             "--remote-ip",
             metavar="<ip-address>",
             help=_("Remote IP address block (may use CIDR notation; "
-                   "default for IPv4 rule: 0.0.0.0/0)"),
+                   "default for IPv4 rule: 0.0.0.0/0, "
+                   "default for IPv6 rule: ::/0)"),
         )
         remote_group.add_argument(
             "--remote-group",
             metavar="<group>",
             help=_("Remote security group (name or ID)"),
         )
-        # Handle deprecated options
-        # NOTE(dtroyer): --src-ip and --src-group were deprecated in Nov 2016.
-        #                Do not remove before 4.x release or Nov 2017.
-        remote_group.add_argument(
-            "--src-ip",
-            metavar="<ip-address>",
-            help=argparse.SUPPRESS,
-        )
-        remote_group.add_argument(
-            "--src-group",
-            metavar="<group>",
-            help=argparse.SUPPRESS,
-        )
         return parser
 
     def update_parser_network(self, parser):
@@ -168,7 +173,7 @@ class CreateSecurityGroupRule(common.NetworkAndComputeShowOne):
                    "ipv6-encap, ipv6-frag, ipv6-icmp, ipv6-nonxt, "
                    "ipv6-opts, ipv6-route, ospf, pgm, rsvp, sctp, tcp, "
                    "udp, udplite, vrrp and integer representations [0-255] "
-                   "or any; default: tcp)")
+                   "or any; default: any (all protocols))")
         )
         protocol_group.add_argument(
             '--proto',
@@ -233,8 +238,8 @@ class CreateSecurityGroupRule(common.NetworkAndComputeShowOne):
         )
         return parser
 
-    def _get_protocol(self, parsed_args):
-        protocol = 'tcp'
+    def _get_protocol(self, parsed_args, default_protocol='any'):
+        protocol = default_protocol
         if parsed_args.protocol is not None:
             protocol = parsed_args.protocol
         if parsed_args.proto is not None:
@@ -243,6 +248,14 @@ class CreateSecurityGroupRule(common.NetworkAndComputeShowOne):
             protocol = None
         return protocol
 
+    def _get_ethertype(self, parsed_args, protocol):
+        ethertype = 'IPv4'
+        if parsed_args.ethertype is not None:
+            ethertype = parsed_args.ethertype
+        elif self._is_ipv6_protocol(protocol):
+            ethertype = 'IPv6'
+        return ethertype
+
     def _is_ipv6_protocol(self, protocol):
         # NOTE(rtheis): Neutron has deprecated protocol icmpv6.
         # However, while the OSC CLI doesn't document the protocol,
@@ -277,12 +290,8 @@ class CreateSecurityGroupRule(common.NetworkAndComputeShowOne):
 
         # NOTE(rtheis): Use ethertype specified else default based
         # on IP protocol.
-        if parsed_args.ethertype:
-            attrs['ethertype'] = parsed_args.ethertype
-        elif self._is_ipv6_protocol(attrs['protocol']):
-            attrs['ethertype'] = 'IPv6'
-        else:
-            attrs['ethertype'] = 'IPv4'
+        attrs['ethertype'] = self._get_ethertype(parsed_args,
+                                                 attrs['protocol'])
 
         # NOTE(rtheis): Validate the port range and ICMP type and code.
         # It would be ideal if argparse could do this.
@@ -310,33 +319,17 @@ class CreateSecurityGroupRule(common.NetworkAndComputeShowOne):
         if parsed_args.icmp_code is not None and parsed_args.icmp_code >= 0:
             attrs['port_range_max'] = parsed_args.icmp_code
 
-        # NOTE(dtroyer): --src-ip and --src-group were deprecated in Nov 2016.
-        #                Do not remove before 4.x release or Nov 2017.
-        if not (parsed_args.remote_group is None and
-                parsed_args.src_group is None):
+        if parsed_args.remote_group is not None:
             attrs['remote_group_id'] = client.find_security_group(
-                parsed_args.remote_group or parsed_args.src_group,
+                parsed_args.remote_group,
                 ignore_missing=False
             ).id
-            if parsed_args.src_group:
-                LOG.warning(
-                    _("The %(old)s option is deprecated, "
-                      "please use %(new)s instead."),
-                    {'old': '--src-group', 'new': '--remote-group'},
-                )
-        elif not (parsed_args.remote_ip is None and
-                  parsed_args.src_ip is None):
-            attrs['remote_ip_prefix'] = (
-                parsed_args.remote_ip or parsed_args.src_ip
-            )
-            if parsed_args.src_ip:
-                LOG.warning(
-                    _("The %(old)s option is deprecated, "
-                      "please use %(new)s instead."),
-                    {'old': '--src-ip', 'new': '--remote-ip'},
-                )
+        elif parsed_args.remote_ip is not None:
+            attrs['remote_ip_prefix'] = parsed_args.remote_ip
         elif attrs['ethertype'] == 'IPv4':
             attrs['remote_ip_prefix'] = '0.0.0.0/0'
+        elif attrs['ethertype'] == 'IPv6':
+            attrs['remote_ip_prefix'] = '::/0'
         attrs['security_group_id'] = security_group_id
         if parsed_args.project is not None:
             identity_client = self.app.client_manager.identity
@@ -350,40 +343,24 @@ class CreateSecurityGroupRule(common.NetworkAndComputeShowOne):
         # Create and show the security group rule.
         obj = client.create_security_group_rule(**attrs)
         display_columns, columns = _get_columns(obj)
-        data = utils.get_item_properties(obj, columns)
+        data = utils.get_item_properties(obj, columns, formatters=_formatters)
         return (display_columns, data)
 
     def take_action_compute(self, client, parsed_args):
         group = client.api.security_group_find(parsed_args.group)
-        protocol = self._get_protocol(parsed_args)
+        protocol = self._get_protocol(parsed_args, default_protocol='tcp')
         if protocol == 'icmp':
             from_port, to_port = -1, -1
         else:
             from_port, to_port = parsed_args.dst_port
 
-        # NOTE(dtroyer): --src-ip and --src-group were deprecated in Nov 2016.
-        #                Do not remove before 4.x release or Nov 2017.
         remote_ip = None
-        if not (parsed_args.remote_group is None and
-                parsed_args.src_group is None):
+        if parsed_args.remote_group is not None:
             parsed_args.remote_group = client.api.security_group_find(
-                parsed_args.remote_group or parsed_args.src_group,
+                parsed_args.remote_group,
             )['id']
-            if parsed_args.src_group:
-                LOG.warning(
-                    _("The %(old)s option is deprecated, "
-                      "please use %(new)s instead."),
-                    {'old': '--src-group', 'new': '--remote-group'},
-                )
-        if not (parsed_args.remote_ip is None and
-                parsed_args.src_ip is None):
-            remote_ip = parsed_args.remote_ip or parsed_args.src_ip
-            if parsed_args.src_ip:
-                LOG.warning(
-                    _("The %(old)s option is deprecated, "
-                      "please use %(new)s instead."),
-                    {'old': '--src-ip', 'new': '--remote-ip'},
-                )
+        if parsed_args.remote_ip is not None:
+            remote_ip = parsed_args.remote_ip
         else:
             remote_ip = '0.0.0.0/0'
 
@@ -434,6 +411,7 @@ class ListSecurityGroupRule(common.NetworkAndComputeLister):
         """
         rule = rule.to_dict()
         rule['port_range'] = _format_network_port_range(rule)
+        rule['remote_ip_prefix'] = _format_remote_ip_prefix(rule)
         return rule
 
     def update_parser_common(self, parser):
@@ -462,8 +440,14 @@ class ListSecurityGroupRule(common.NetworkAndComputeLister):
                    "ah, dhcp, egp, esp, gre, icmp, igmp, "
                    "ipv6-encap, ipv6-frag, ipv6-icmp, ipv6-nonxt, "
                    "ipv6-opts, ipv6-route, ospf, pgm, rsvp, sctp, tcp, "
-                   "udp, udplite, vrrp and integer representations [0-255])."
-                   )
+                   "udp, udplite, vrrp and integer representations [0-255] "
+                   "or any; default: any (all protocols))")
+        )
+        parser.add_argument(
+            '--ethertype',
+            metavar='<ethertype>',
+            type=_convert_to_lowercase,
+            help=_("List rules by the Ethertype (IPv4 or IPv6)")
         )
         direction_group = parser.add_mutually_exclusive_group()
         direction_group.add_argument(
@@ -505,11 +489,12 @@ class ListSecurityGroupRule(common.NetworkAndComputeLister):
         column_headers = (
             'ID',
             'IP Protocol',
+            'Ethertype',
             'IP Range',
             'Port Range',
         )
         if parsed_args.long:
-            column_headers = column_headers + ('Direction', 'Ethertype',)
+            column_headers = column_headers + ('Direction',)
         column_headers = column_headers + ('Remote Security Group',)
         if parsed_args.group is None:
             column_headers = column_headers + ('Security Group',)
@@ -520,11 +505,12 @@ class ListSecurityGroupRule(common.NetworkAndComputeLister):
         columns = (
             'id',
             'protocol',
+            'ether_type',
             'remote_ip_prefix',
             'port_range',
         )
         if parsed_args.long:
-            columns = columns + ('direction', 'ether_type',)
+            columns = columns + ('direction',)
         columns = columns + ('remote_group_id',)
 
         # Get the security group rules using the requested query.
@@ -563,6 +549,7 @@ class ListSecurityGroupRule(common.NetworkAndComputeLister):
         columns = (
             "ID",
             "IP Protocol",
+            "Ethertype",
             "IP Range",
             "Port Range",
             "Remote Security Group",
@@ -611,8 +598,11 @@ class ShowSecurityGroupRule(common.NetworkAndComputeShowOne):
     def take_action_network(self, client, parsed_args):
         obj = client.find_security_group_rule(parsed_args.rule,
                                               ignore_missing=False)
+        # necessary for old rules that have None in this field
+        if not obj['remote_ip_prefix']:
+            obj['remote_ip_prefix'] = _format_remote_ip_prefix(obj)
         display_columns, columns = _get_columns(obj)
-        data = utils.get_item_properties(obj, columns)
+        data = utils.get_item_properties(obj, columns, formatters=_formatters)
         return (display_columns, data)
 
     def take_action_compute(self, client, parsed_args):
