@@ -17,6 +17,7 @@
 
 import logging
 
+from osc_lib.cli import format_columns
 from osc_lib.cli import parseractions
 from osc_lib.command import command
 from osc_lib import exceptions
@@ -139,7 +140,7 @@ class ListObject(command.Lister):
         )
         parser.add_argument(
             "--limit",
-            metavar="<limit>",
+            metavar="<num-objects>",
             type=int,
             help=_("Limit the number of objects returned"),
         )
@@ -204,7 +205,8 @@ class SaveObject(command.Command):
         parser.add_argument(
             "--file",
             metavar="<filename>",
-            help=_("Destination filename (defaults to object name)"),
+            help=_("Destination filename (defaults to object name); using '-'"
+                   " as the filename will print the file to stdout"),
         )
         parser.add_argument(
             'container',
@@ -283,7 +285,7 @@ class ShowObject(command.ShowOne):
             object=parsed_args.object,
         )
         if 'properties' in data:
-            data['properties'] = utils.format_dict(data.pop('properties'))
+            data['properties'] = format_columns.DictColumn(data['properties'])
 
         return zip(*sorted(six.iteritems(data)))
 
