@@ -15,6 +15,10 @@
 
 import copy
 
+import mock
+from osc_lib import exceptions
+from osc_lib import utils
+
 from openstackclient.identity.v3 import role
 from openstackclient.tests.unit import fakes
 from openstackclient.tests.unit.identity.v3 import fakes as identity_fakes
@@ -269,6 +273,22 @@ class TestRoleAdd(TestRole):
         )
         self.assertIsNone(result)
 
+    def test_role_add_with_error(self):
+        arglist = [
+            identity_fakes.role_name,
+        ]
+        verifylist = [
+            ('user', None),
+            ('group', None),
+            ('domain', None),
+            ('project', None),
+            ('role', identity_fakes.role_name),
+            ('inherited', False),
+        ]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+        self.assertRaises(exceptions.CommandError,
+                          self.cmd.take_action, parsed_args)
+
 
 class TestRoleAddInherited(TestRoleAdd, TestRoleInherited):
     pass
@@ -428,6 +448,36 @@ class TestRoleDelete(TestRole):
         )
         self.assertIsNone(result)
 
+    @mock.patch.object(utils, 'find_resource')
+    def test_delete_multi_roles_with_exception(self, find_mock):
+        find_mock.side_effect = [self.roles_mock.get.return_value,
+                                 exceptions.CommandError]
+        arglist = [
+            identity_fakes.role_name,
+            'unexist_role',
+        ]
+        verifylist = [
+            ('roles', arglist),
+        ]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        try:
+            self.cmd.take_action(parsed_args)
+            self.fail('CommandError should be raised.')
+        except exceptions.CommandError as e:
+            self.assertEqual('1 of 2 roles failed to delete.',
+                             str(e))
+
+        find_mock.assert_any_call(self.roles_mock,
+                                  identity_fakes.role_name,
+                                  domain_id=None)
+        find_mock.assert_any_call(self.roles_mock,
+                                  'unexist_role',
+                                  domain_id=None)
+
+        self.assertEqual(2, find_mock.call_count)
+        self.roles_mock.delete.assert_called_once_with(identity_fakes.role_id)
+
 
 class TestRoleList(TestRole):
 
@@ -458,21 +508,6 @@ class TestRoleList(TestRole):
             copy.deepcopy(identity_fakes.DOMAIN),
             loaded=True,
         )
-        self.projects_mock.get.return_value = fakes.FakeResource(
-            None,
-            copy.deepcopy(identity_fakes.PROJECT),
-            loaded=True,
-        )
-        self.users_mock.get.return_value = fakes.FakeResource(
-            None,
-            copy.deepcopy(identity_fakes.USER),
-            loaded=True,
-        )
-        self.groups_mock.get.return_value = fakes.FakeResource(
-            None,
-            copy.deepcopy(identity_fakes.GROUP),
-            loaded=True,
-        )
 
         # Get the command object to test
         self.cmd = role.ListRole(self.app, None)
@@ -492,212 +527,6 @@ class TestRoleList(TestRole):
         self.assertEqual(self.columns, columns)
         self.assertEqual(self.datalist, tuple(data))
 
-    def test_user_list_inherited(self):
-        arglist = [
-            '--user', identity_fakes.user_id,
-            '--inherited',
-        ]
-        verifylist = [
-            ('user', identity_fakes.user_id),
-            ('inherited', True),
-        ]
-        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
-
-        # In base command class Lister in cliff, abstract method take_action()
-        # returns a tuple containing the column names and an iterable
-        # containing the data to be listed.
-        columns, data = self.cmd.take_action(parsed_args)
-
-        # Set expected values
-        kwargs = {
-            'domain': 'default',
-            'user': self.users_mock.get(),
-            'os_inherit_extension_inherited': True,
-        }
-        # RoleManager.list(user=, group=, domain=, project=, **kwargs)
-        self.roles_mock.list.assert_called_with(
-            **kwargs
-        )
-
-        self.assertEqual(self.columns, columns)
-        self.assertEqual(self.datalist, tuple(data))
-
-    def test_user_list_user(self):
-        arglist = [
-            '--user', identity_fakes.user_id,
-        ]
-        verifylist = [
-            ('user', identity_fakes.user_id),
-        ]
-        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
-
-        # In base command class Lister in cliff, abstract method take_action()
-        # returns a tuple containing the column names and an iterable
-        # containing the data to be listed.
-        columns, data = self.cmd.take_action(parsed_args)
-
-        # Set expected values
-        kwargs = {
-            'domain': 'default',
-            'user': self.users_mock.get(),
-            'os_inherit_extension_inherited': False
-        }
-        # RoleManager.list(user=, group=, domain=, project=, **kwargs)
-        self.roles_mock.list.assert_called_with(
-            **kwargs
-        )
-
-        self.assertEqual(self.columns, columns)
-        self.assertEqual(self.datalist, tuple(data))
-
-    def test_role_list_domain_user(self):
-        arglist = [
-            '--domain', identity_fakes.domain_name,
-            '--user', identity_fakes.user_id,
-        ]
-        verifylist = [
-            ('domain', identity_fakes.domain_name),
-            ('user', identity_fakes.user_id),
-        ]
-        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
-
-        # In base command class Lister in cliff, abstract method take_action()
-        # returns a tuple containing the column names and an iterable
-        # containing the data to be listed.
-        columns, data = self.cmd.take_action(parsed_args)
-
-        # Set expected values
-        kwargs = {
-            'domain': self.domains_mock.get(),
-            'user': self.users_mock.get(),
-            'os_inherit_extension_inherited': False
-        }
-        # RoleManager.list(user=, group=, domain=, project=, **kwargs)
-        self.roles_mock.list.assert_called_with(
-            **kwargs
-        )
-
-        collist = ('ID', 'Name', 'Domain', 'User')
-        self.assertEqual(collist, columns)
-        datalist = ((
-            identity_fakes.role_id,
-            identity_fakes.role_name,
-            identity_fakes.domain_name,
-            identity_fakes.user_name,
-        ), )
-        self.assertEqual(datalist, tuple(data))
-
-    def test_role_list_domain_group(self):
-        arglist = [
-            '--domain', identity_fakes.domain_name,
-            '--group', identity_fakes.group_id,
-        ]
-        verifylist = [
-            ('domain', identity_fakes.domain_name),
-            ('group', identity_fakes.group_id),
-        ]
-        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
-
-        # In base command class Lister in cliff, abstract method take_action()
-        # returns a tuple containing the column names and an iterable
-        # containing the data to be listed.
-        columns, data = self.cmd.take_action(parsed_args)
-
-        # Set expected values
-        kwargs = {
-            'domain': self.domains_mock.get(),
-            'group': self.groups_mock.get(),
-            'os_inherit_extension_inherited': False
-        }
-        # RoleManager.list(user=, group=, domain=, project=, **kwargs)
-        self.roles_mock.list.assert_called_with(
-            **kwargs
-        )
-
-        collist = ('ID', 'Name', 'Domain', 'Group')
-        self.assertEqual(collist, columns)
-        datalist = ((
-            identity_fakes.role_id,
-            identity_fakes.role_name,
-            identity_fakes.domain_name,
-            identity_fakes.group_name,
-        ), )
-        self.assertEqual(datalist, tuple(data))
-
-    def test_role_list_project_user(self):
-        arglist = [
-            '--project', identity_fakes.project_name,
-            '--user', identity_fakes.user_id,
-        ]
-        verifylist = [
-            ('project', identity_fakes.project_name),
-            ('user', identity_fakes.user_id),
-        ]
-        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
-
-        # In base command class Lister in cliff, abstract method take_action()
-        # returns a tuple containing the column names and an iterable
-        # containing the data to be listed.
-        columns, data = self.cmd.take_action(parsed_args)
-
-        # Set expected values
-        kwargs = {
-            'project': self.projects_mock.get(),
-            'user': self.users_mock.get(),
-            'os_inherit_extension_inherited': False
-        }
-        # RoleManager.list(user=, group=, domain=, project=, **kwargs)
-        self.roles_mock.list.assert_called_with(
-            **kwargs
-        )
-
-        collist = ('ID', 'Name', 'Project', 'User')
-        self.assertEqual(collist, columns)
-        datalist = ((
-            identity_fakes.role_id,
-            identity_fakes.role_name,
-            identity_fakes.project_name,
-            identity_fakes.user_name,
-        ), )
-        self.assertEqual(datalist, tuple(data))
-
-    def test_role_list_project_group(self):
-        arglist = [
-            '--project', identity_fakes.project_name,
-            '--group', identity_fakes.group_id,
-        ]
-        verifylist = [
-            ('project', identity_fakes.project_name),
-            ('group', identity_fakes.group_id),
-        ]
-        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
-
-        # In base command class Lister in cliff, abstract method take_action()
-        # returns a tuple containing the column names and an iterable
-        # containing the data to be listed.
-        columns, data = self.cmd.take_action(parsed_args)
-
-        # Set expected values
-        kwargs = {
-            'project': self.projects_mock.get(),
-            'group': self.groups_mock.get(),
-            'os_inherit_extension_inherited': False
-        }
-        # RoleManager.list(user=, group=, domain=, project=, **kwargs)
-        self.roles_mock.list.assert_called_with(
-            **kwargs
-        )
-
-        collist = ('ID', 'Name', 'Project', 'Group')
-        self.assertEqual(collist, columns)
-        datalist = ((
-            identity_fakes.role_id,
-            identity_fakes.role_name,
-            identity_fakes.project_name,
-            identity_fakes.group_name,
-        ), )
-        self.assertEqual(datalist, tuple(data))
-
     def test_role_list_domain_role(self):
         self.roles_mock.list.return_value = [
             fakes.FakeResource(
@@ -948,6 +777,22 @@ class TestRoleRemove(TestRole):
         )
         self.assertIsNone(result)
 
+    def test_role_remove_with_error(self):
+        arglist = [
+            identity_fakes.role_name,
+        ]
+        verifylist = [
+            ('user', None),
+            ('group', None),
+            ('domain', None),
+            ('project', None),
+            ('role', identity_fakes.role_name),
+            ('inherited', False),
+        ]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+        self.assertRaises(exceptions.CommandError,
+                          self.cmd.take_action, parsed_args)
+
 
 class TestRoleSet(TestRole):
 
