@@ -14,8 +14,8 @@
 import mock
 from mock import call
 
+from osc_lib.cli import format_columns
 from osc_lib import exceptions
-from osc_lib import utils as osc_utils
 
 from openstackclient.network.v2 import router
 from openstackclient.tests.unit.identity.v3 import fakes as identity_fakes_v3
@@ -132,19 +132,19 @@ class TestCreateRouter(TestRouter):
         'tags',
     )
     data = (
-        router._format_admin_state(new_router.admin_state_up),
-        osc_utils.format_list(new_router.availability_zone_hints),
-        osc_utils.format_list(new_router.availability_zones),
+        router.AdminStateColumn(new_router.admin_state_up),
+        format_columns.ListColumn(new_router.availability_zone_hints),
+        format_columns.ListColumn(new_router.availability_zones),
         new_router.description,
         new_router.distributed,
-        router._format_router_info(new_router.external_gateway_info),
+        router.RouterInfoColumn(new_router.external_gateway_info),
         new_router.ha,
         new_router.id,
         new_router.name,
         new_router.tenant_id,
-        router._format_routes(new_router.routes),
+        router.RoutesColumn(new_router.routes),
         new_router.status,
-        osc_utils.format_list(new_router.tags),
+        format_columns.ListColumn(new_router.tags),
     )
 
     def setUp(self):
@@ -184,7 +184,7 @@ class TestCreateRouter(TestRouter):
         })
         self.assertFalse(self.network.set_tags.called)
         self.assertEqual(self.columns, columns)
-        self.assertEqual(self.data, data)
+        self.assertItemEqual(self.data, data)
 
     def _test_create_with_ha_options(self, option, ha):
         arglist = [
@@ -208,7 +208,7 @@ class TestCreateRouter(TestRouter):
             'ha': ha,
         })
         self.assertEqual(self.columns, columns)
-        self.assertEqual(self.data, data)
+        self.assertItemEqual(self.data, data)
 
     def test_create_with_ha_option(self):
         self._test_create_with_ha_options('--ha', True)
@@ -237,7 +237,7 @@ class TestCreateRouter(TestRouter):
             'distributed': distributed,
         })
         self.assertEqual(self.columns, columns)
-        self.assertEqual(self.data, data)
+        self.assertItemEqual(self.data, data)
 
     def test_create_with_distributed_option(self):
         self._test_create_with_distributed_options('--distributed', True)
@@ -268,7 +268,7 @@ class TestCreateRouter(TestRouter):
         })
 
         self.assertEqual(self.columns, columns)
-        self.assertEqual(self.data, data)
+        self.assertItemEqual(self.data, data)
 
     def _test_create_with_tag(self, add_tags=True):
         arglist = [self.new_router.name]
@@ -301,7 +301,7 @@ class TestCreateRouter(TestRouter):
         else:
             self.assertFalse(self.network.set_tags.called)
         self.assertEqual(self.columns, columns)
-        self.assertEqual(self.data, data)
+        self.assertItemEqual(self.data, data)
 
     def test_create_with_tags(self):
         self._test_create_with_tag(add_tags=True)
@@ -422,7 +422,7 @@ class TestListRouter(TestRouter):
             r.id,
             r.name,
             r.status,
-            router._format_admin_state(r.admin_state_up),
+            router.AdminStateColumn(r.admin_state_up),
             r.tenant_id,
             r.distributed,
             r.ha,
@@ -447,10 +447,10 @@ class TestListRouter(TestRouter):
         r = routers[i]
         data_long.append(
             data[i] + (
-                router._format_routes(r.routes),
-                router._format_router_info(r.external_gateway_info),
-                osc_utils.format_list(r.availability_zones),
-                osc_utils.format_list(r.tags),
+                router.RoutesColumn(r.routes),
+                router.RouterInfoColumn(r.external_gateway_info),
+                format_columns.ListColumn(r.availability_zones),
+                format_columns.ListColumn(r.tags),
             )
         )
     data_long_no_az = []
@@ -458,9 +458,9 @@ class TestListRouter(TestRouter):
         r = routers[i]
         data_long_no_az.append(
             data[i] + (
-                router._format_routes(r.routes),
-                router._format_router_info(r.external_gateway_info),
-                osc_utils.format_list(r.tags),
+                router.RoutesColumn(r.routes),
+                router.RouterInfoColumn(r.external_gateway_info),
+                format_columns.ListColumn(r.tags),
             )
         )
 
@@ -494,7 +494,7 @@ class TestListRouter(TestRouter):
 
         self.network.routers.assert_called_once_with()
         self.assertEqual(self.columns, columns)
-        self.assertEqual(self.data, list(data))
+        self.assertListItemEqual(self.data, list(data))
 
     def test_router_list_no_ha_no_distributed(self):
         _routers = network_fakes.FakeRouter.create_routers({
@@ -531,7 +531,7 @@ class TestListRouter(TestRouter):
 
         self.network.routers.assert_called_once_with()
         self.assertEqual(self.columns_long, columns)
-        self.assertEqual(self.data_long, list(data))
+        self.assertListItemEqual(self.data_long, list(data))
 
     def test_router_list_long_no_az(self):
         arglist = [
@@ -552,7 +552,7 @@ class TestListRouter(TestRouter):
 
         self.network.routers.assert_called_once_with()
         self.assertEqual(self.columns_long_no_az, columns)
-        self.assertEqual(self.data_long_no_az, list(data))
+        self.assertListItemEqual(self.data_long_no_az, list(data))
 
     def test_list_name(self):
         test_name = "fakename"
@@ -570,7 +570,7 @@ class TestListRouter(TestRouter):
             **{'name': test_name}
         )
         self.assertEqual(self.columns, columns)
-        self.assertEqual(self.data, list(data))
+        self.assertListItemEqual(self.data, list(data))
 
     def test_router_list_enable(self):
         arglist = [
@@ -587,7 +587,7 @@ class TestListRouter(TestRouter):
             **{'admin_state_up': True, 'is_admin_state_up': True}
         )
         self.assertEqual(self.columns, columns)
-        self.assertEqual(self.data, list(data))
+        self.assertListItemEqual(self.data, list(data))
 
     def test_router_list_disable(self):
         arglist = [
@@ -605,7 +605,7 @@ class TestListRouter(TestRouter):
         )
 
         self.assertEqual(self.columns, columns)
-        self.assertEqual(self.data, list(data))
+        self.assertListItemEqual(self.data, list(data))
 
     def test_router_list_project(self):
         project = identity_fakes_v3.FakeProject.create_one_project()
@@ -623,7 +623,7 @@ class TestListRouter(TestRouter):
 
         self.network.routers.assert_called_once_with(**filters)
         self.assertEqual(self.columns, columns)
-        self.assertEqual(self.data, list(data))
+        self.assertListItemEqual(self.data, list(data))
 
     def test_router_list_project_domain(self):
         project = identity_fakes_v3.FakeProject.create_one_project()
@@ -643,7 +643,7 @@ class TestListRouter(TestRouter):
 
         self.network.routers.assert_called_once_with(**filters)
         self.assertEqual(self.columns, columns)
-        self.assertEqual(self.data, list(data))
+        self.assertListItemEqual(self.data, list(data))
 
     def test_router_list_agents_no_args(self):
         arglist = [
@@ -671,7 +671,7 @@ class TestListRouter(TestRouter):
         self.network.agent_hosted_routers(
             *attrs)
         self.assertEqual(self.columns, columns)
-        self.assertEqual(self.data, list(data))
+        self.assertListItemEqual(self.data, list(data))
 
     def test_list_with_tag_options(self):
         arglist = [
@@ -696,7 +696,7 @@ class TestListRouter(TestRouter):
                'not_any_tags': 'black,white'}
         )
         self.assertEqual(self.columns, columns)
-        self.assertEqual(self.data, list(data))
+        self.assertListItemEqual(self.data, list(data))
 
 
 class TestRemovePortFromRouter(TestRouter):
@@ -939,52 +939,6 @@ class TestSetRouter(TestRouter):
             _testrouter, **attrs)
         self.assertIsNone(result)
 
-    def test_set_clear_routes(self):
-        arglist = [
-            self._router.name,
-            '--clear-routes',
-        ]
-        verifylist = [
-            ('router', self._router.name),
-            ('clear_routes', True),
-        ]
-        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
-
-        result = self.cmd.take_action(parsed_args)
-
-        attrs = {
-            'routes': [],
-        }
-        self.network.update_router.assert_called_once_with(
-            self._router, **attrs)
-        self.assertIsNone(result)
-
-    def test_overwrite_route_clear_routes(self):
-        _testrouter = network_fakes.FakeRouter.create_one_router(
-            {'routes': [{"destination": "10.0.0.2",
-                         "nexthop": "1.1.1.1"}]})
-        self.network.find_router = mock.Mock(return_value=_testrouter)
-        arglist = [
-            _testrouter.name,
-            '--route', 'destination=10.20.30.0/24,gateway=10.20.30.1',
-            '--clear-routes',
-        ]
-        verifylist = [
-            ('router', _testrouter.name),
-            ('routes', [{'destination': '10.20.30.0/24',
-                         'gateway': '10.20.30.1'}]),
-            ('clear_routes', True),
-        ]
-        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
-        result = self.cmd.take_action(parsed_args)
-        attrs = {
-            'routes': [{'destination': '10.20.30.0/24',
-                        'nexthop': '10.20.30.1'}]
-        }
-        self.network.update_router.assert_called_once_with(
-            _testrouter, **attrs)
-        self.assertIsNone(result)
-
     def test_set_nothing(self):
         arglist = [
             self._router.name,
@@ -1260,20 +1214,20 @@ class TestShowRouter(TestRouter):
         'tags',
     )
     data = (
-        router._format_admin_state(_router.admin_state_up),
-        osc_utils.format_list(_router.availability_zone_hints),
-        osc_utils.format_list(_router.availability_zones),
+        router.AdminStateColumn(_router.admin_state_up),
+        format_columns.ListColumn(_router.availability_zone_hints),
+        format_columns.ListColumn(_router.availability_zones),
         _router.description,
         _router.distributed,
-        router._format_router_info(_router.external_gateway_info),
+        router.RouterInfoColumn(_router.external_gateway_info),
         _router.ha,
         _router.id,
-        router._format_router_info(_router.interfaces_info),
+        router.RouterInfoColumn(_router.interfaces_info),
         _router.name,
         _router.tenant_id,
-        router._format_routes(_router.routes),
+        router.RoutesColumn(_router.routes),
         _router.status,
-        osc_utils.format_list(_router.tags),
+        format_columns.ListColumn(_router.tags),
     )
 
     def setUp(self):
@@ -1309,7 +1263,7 @@ class TestShowRouter(TestRouter):
             'device_id': self._router.id
         })
         self.assertEqual(self.columns, columns)
-        self.assertEqual(self.data, data)
+        self.assertItemEqual(self.data, data)
 
     def test_show_no_ha_no_distributed(self):
         _router = network_fakes.FakeRouter.create_one_router({
