@@ -18,6 +18,7 @@ from mock import call
 from osc_lib import exceptions
 from osc_lib import utils
 
+from openstackclient.tests.unit import utils as test_utils
 from openstackclient.tests.unit.volume.v2 import fakes as transfer_fakes
 from openstackclient.volume.v2 import volume_transfer_request
 
@@ -85,26 +86,6 @@ class TestTransferAccept(TestTransfer):
         self.assertEqual(self.columns, columns)
         self.assertEqual(self.data, data)
 
-    def test_transfer_accept_deprecated(self):
-        arglist = [
-            self.volume_transfer.id,
-            'key_value',
-        ]
-        verifylist = [
-            ('transfer_request', self.volume_transfer.id),
-            ('old_auth_key', 'key_value'),
-        ]
-        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
-
-        columns, data = self.cmd.take_action(parsed_args)
-
-        self.transfer_mock.accept.assert_called_once_with(
-            self.volume_transfer.id,
-            'key_value',
-        )
-        self.assertEqual(self.columns, columns)
-        self.assertEqual(self.data, data)
-
     def test_transfer_accept_no_option(self):
         arglist = [
             self.volume_transfer.id,
@@ -112,12 +93,13 @@ class TestTransferAccept(TestTransfer):
         verifylist = [
             ('transfer_request', self.volume_transfer.id),
         ]
-        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
         self.assertRaises(
-            exceptions.CommandError,
-            self.cmd.take_action,
-            parsed_args,
+            test_utils.ParserException,
+            self.check_parser,
+            self.cmd,
+            arglist,
+            verifylist,
         )
 
 
