@@ -16,8 +16,11 @@
 """Volume v1 Volume action implementations"""
 
 import argparse
+import functools
 import logging
 
+from cliff import columns as cliff_columns
+from osc_lib.cli import format_columns
 from osc_lib.cli import parseractions
 from osc_lib.command import command
 from osc_lib import exceptions
@@ -30,6 +33,37 @@ from openstackclient.i18n import _
 LOG = logging.getLogger(__name__)
 
 
+class AttachmentsColumn(cliff_columns.FormattableColumn):
+    """Formattable column for attachments column.
+
+    Unlike the parent FormattableColumn class, the initializer of the
+    class takes server_cache as the second argument.
+    osc_lib.utils.get_item_properties instantiate cliff FormattableColumn
+    object with a single parameter "column value", so you need to pass
+    a partially initialized class like
+    ``functools.partial(AttachmentsColumn, server_cache)``.
+    """
+
+    def __init__(self, value, server_cache=None):
+        super(AttachmentsColumn, self).__init__(value)
+        self._server_cache = server_cache or {}
+
+    def human_readable(self):
+        """Return a formatted string of a volume's attached instances
+
+        :rtype: a string of formatted instances
+        """
+
+        msg = ''
+        for attachment in self._value:
+            server = attachment['server_id']
+            if server in self._server_cache.keys():
+                server = self._server_cache[server].name
+            device = attachment['device']
+            msg += 'Attached to %s on %s ' % (server, device)
+        return msg
+
+
 def _check_size_arg(args):
     """Check whether --size option is required or not.
 
@@ -207,12 +241,19 @@ class CreateVolume(command.ShowOne):
         # Map 'metadata' column to 'properties'
         volume._info.update(
             {
-                'properties': utils.format_dict(volume._info.pop('metadata')),
+                'properties':
+                format_columns.DictColumn(volume._info.pop('metadata')),
                 'type': volume._info.pop('volume_type'),
             },
         )
+        # Replace "display_name" by "name", keep consistent in v1 and v2
+        if 'display_name' in volume._info:
+            volume._info.update({'name': volume._info.pop('display_name')})
+        volume_info = utils.backward_compat_col_showone(
+            volume._info, parsed_args.columns, {'display_name': 'name'}
+        )
 
-        return zip(*sorted(six.iteritems(volume._info)))
+        return zip(*sorted(six.iteritems(volume_info)))
 
 
 class DeleteVolume(command.Command):
@@ -291,7 +332,7 @@ class ListVolume(command.Lister):
             '--limit',
             type=int,
             action=parseractions.NonNegativeAction,
-            metavar='<limit>',
+            metavar='<num-volumes>',
             help=_('Maximum number of volumes to display'),
         )
         return parser
@@ -301,22 +342,6 @@ class ListVolume(command.Lister):
         volume_client = self.app.client_manager.volume
         compute_client = self.app.client_manager.compute
 
-        def _format_attach(attachments):
-            """Return a formatted string of a volume's attached instances
-
-            :param attachments: a volume.attachments field
-            :rtype: a string of formatted instances
-            """
-
-            msg = ''
-            for attachment in attachments:
-                server = attachment['server_id']
-                if server in server_cache.keys():
-                    server = server_cache[server].name
-                device = attachment['device']
-                msg += 'Attached to %s on %s ' % (server, device)
-            return msg
-
         if parsed_args.long:
             columns = (
                 'ID',
@@ -330,7 +355,7 @@ class ListVolume(command.Lister):
             )
             column_headers = (
                 'ID',
-                'Display Name',
+                'Name',
                 'Status',
                 'Size',
                 'Type',
@@ -348,7 +373,7 @@ class ListVolume(command.Lister):
             )
             column_headers = (
                 'ID',
-                'Display Name',
+                'Name',
                 'Status',
                 'Size',
                 'Attached to',
@@ -362,6 +387,8 @@ class ListVolume(command.Lister):
         except Exception:
             # Just forget it if there's any trouble
             pass
+        AttachmentsColumnWithCache = functools.partial(
+            AttachmentsColumn, server_cache=server_cache)
 
         search_opts = {
             'all_tenants': parsed_args.all_projects,
@@ -373,12 +400,14 @@ class ListVolume(command.Lister):
             search_opts=search_opts,
             limit=parsed_args.limit,
         )
+        column_headers = utils.backward_compat_col_lister(
+            column_headers, parsed_args.columns, {'Display Name': 'Name'})
 
         return (column_headers,
                 (utils.get_item_properties(
                     s, columns,
-                    formatters={'Metadata': utils.format_dict,
-                                'Attachments': _format_attach},
+                    formatters={'Metadata': format_columns.DictColumn,
+                                'Attachments': AttachmentsColumnWithCache},
                 ) for s in data))
 
 
@@ -567,7 +596,8 @@ class ShowVolume(command.ShowOne):
         # Map 'metadata' column to 'properties'
         volume._info.update(
             {
-                'properties': utils.format_dict(volume._info.pop('metadata')),
+                'properties':
+                format_columns.DictColumn(volume._info.pop('metadata')),
                 'type': volume._info.pop('volume_type'),
             },
         )
@@ -576,7 +606,15 @@ class ShowVolume(command.ShowOne):
                 {'project_id': volume._info.pop(
                     'os-vol-tenant-attr:tenant_id')}
             )
-        return zip(*sorted(six.iteritems(volume._info)))
+        # Replace "display_name" by "name", keep consistent in v1 and v2
+        if 'display_name' in volume._info:
+            volume._info.update({'name': volume._info.pop('display_name')})
+
+        volume_info = utils.backward_compat_col_showone(
+            volume._info, parsed_args.columns, {'display_name': 'name'}
+        )
+
+        return zip(*sorted(six.iteritems(volume_info)))
 
 
 class UnsetVolume(command.Command):
