@@ -17,6 +17,7 @@
 
 import logging
 
+from osc_lib.cli import format_columns
 from osc_lib.cli import parseractions
 from osc_lib.command import command
 from osc_lib import exceptions
@@ -96,7 +97,8 @@ class CreateQos(command.ShowOne):
         qos_spec = volume_client.qos_specs.create(parsed_args.name, specs)
 
         qos_spec._info.update(
-            {'properties': utils.format_dict(qos_spec._info.pop('specs'))}
+            {'properties':
+             format_columns.DictColumn(qos_spec._info.pop('specs'))}
         )
         return zip(*sorted(six.iteritems(qos_spec._info)))
 
@@ -187,11 +189,20 @@ class ListQos(command.Lister):
         qos_specs_list = volume_client.qos_specs.list()
 
         for qos in qos_specs_list:
-            qos_associations = volume_client.qos_specs.get_associations(qos)
-            if qos_associations:
-                associations = [association.name
-                                for association in qos_associations]
-                qos._info.update({'associations': associations})
+            try:
+                qos_associations = volume_client.qos_specs.get_associations(
+                    qos,
+                )
+                if qos_associations:
+                    associations = [
+                        association.name for association in qos_associations
+                    ]
+                    qos._info.update({'associations': associations})
+            except Exception as ex:
+                if type(ex).__name__ == 'NotFound':
+                    qos._info.update({'associations': None})
+                else:
+                    raise
 
         display_columns = (
             'ID', 'Name', 'Consumer', 'Associations', 'Properties')
@@ -201,8 +212,8 @@ class ListQos(command.Lister):
                 (utils.get_dict_properties(
                     s._info, columns,
                     formatters={
-                        'Specs': utils.format_dict,
-                        'Associations': utils.format_list
+                        'Specs': format_columns.DictColumn,
+                        'Associations': format_columns.ListColumn
                     },
                 ) for s in qos_specs_list))
 
@@ -258,10 +269,11 @@ class ShowQos(command.ShowOne):
             associations = [association.name
                             for association in qos_associations]
             qos_spec._info.update({
-                'associations': utils.format_list(associations)
+                'associations': format_columns.ListColumn(associations)
             })
         qos_spec._info.update(
-            {'properties': utils.format_dict(qos_spec._info.pop('specs'))})
+            {'properties':
+             format_columns.DictColumn(qos_spec._info.pop('specs'))})
 
         return zip(*sorted(six.iteritems(qos_spec._info)))
 
